﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace boca_sample
{
    public partial class FrmSpHead : Form
    {
        private FrmBoca m_parent;
        
        public FrmSpHead(FrmBoca frm1)
        {
            InitializeComponent();
            m_parent = frm1;
        }

        private void LstType_SelectedIndexChanged(object sender, EventArgs e)
        {
            //error check range 0 to 2 which represents No, SPC, RADJ
            if ((LstType.SelectedIndex >= 0) && (LstType.SelectedIndex <= 2))
            {
                TxtType.Text = LstType.Text;            //display head type selection
                
                //if head type is SPC or RADJ then enable path drop down menu
                if (LstType.SelectedIndex > 0)
                {
                    LstPath.Enabled = true;
                    Text = "Select Path";
                }
                else
                    LstPath.Enabled = false;

                //if head type is RADJ then enable size drop down menu
                if (LstType.SelectedIndex > 1)
                    LstSize.Enabled = true;
                else
                    LstSize.Enabled = false;
            }
            else
                TxtType.Text = "NO";        //4.0 inch head
        }

        private void LstPath_SelectedIndexChanged(object sender, EventArgs e)
        {
            //error check range 0 to 2 which represents P1, P2 and BOTH
            if ((LstPath.SelectedIndex >= 0) && (LstPath.SelectedIndex <= 2))
            {
                TxtPath.Text = LstPath.Text;
                if(TxtType.Text ==  "RADJ")
                    Text = "Select Size";
            }
            else
                TxtPath.Text = "";

        }

        private void LstSize_SelectedIndexChanged(object sender, EventArgs e)
        {
            //error check range 0 to 5 which represents 2.0, 2.125, 2.5, 2.7, 3.0, 3.25
            if ((LstSize.SelectedIndex >= 0) && (LstSize.SelectedIndex <= 5))
                TxtSize.Text = LstSize.Text;
            else
                TxtSize.Text = "";
        }

        private void FrmSpHead_Load(object sender, EventArgs e)
        {
            Text = "Select Head Type";
            LstPath.Enabled = false;
            LstSize.Enabled = false;
        }

        private void CmdOk_Click(object sender, EventArgs e)
        {
           
            string fgl_command = "";
            string text_command = "";

            //If values are blank, set up defaults
            if (TxtType.Text == "")
                TxtType.Text = "NO";
            if (TxtPath.Text == "")
                TxtPath.Text = "P1";
            if (TxtSize.Text == "")
                TxtSize.Text = "2.0";

            switch (TxtType.Text)
            {
                case "Full Size":
                    fgl_command = "<sph0>";                     //No Special Head
                    text_command = "No Special Head";
                    break;
                case "Special":
                    switch (TxtPath.Text)
                    {
                        case "P1":
                            fgl_command = "<sph1>";             //Special Head Size Path 1
                            text_command = "Special Head Size Path 1";
                            break;
                        case "P2":
                            fgl_command = "<sph2>";             //Special Head Size Path 2
                            text_command = "Special Head Size Path 2";
                            break;
                        case "BOTH":
                            fgl_command = "<sph3>";             //Special Head Size Both Paths
                            text_command = "Special Head Size Both Paths";
                            break;
                        default:
                            fgl_command = "<sph1>";             //Special Head Size Path 1
                            text_command = "Special Head Size Path 1";
                            break;
                    }
                    break;
                case "Rev-Adj":
                    switch (TxtPath.Text)
                    {
                        case "P1":
                            if (TxtSize.Text == "2.0")
                                fgl_command = "<sph4>";
                            else if (TxtSize.Text == "2.125")
                                fgl_command = "<sph16>";
                            else if (TxtSize.Text == "2.5")
                                fgl_command = "<sph7>";
                            else if (TxtSize.Text == "2.7")
                                fgl_command = "<sph10>";
                            else if (TxtSize.Text == "3.0")
                                fgl_command = "<sph13>";
                            else if (TxtSize.Text == "3.25")
                                fgl_command = "<sph19>";
                            text_command = "Reverse Adjustable " + TxtSize.Text + " Path 1";
                            break;
                        case "P2":
                            if (TxtSize.Text == "2.0")
                                fgl_command = "<sph5>";
                            else if (TxtSize.Text == "2.125")
                                fgl_command = "<sph17>";
                            else if (TxtSize.Text == "2.5")
                                fgl_command = "<sph8>";
                            else if (TxtSize.Text == "2.7")
                                fgl_command = "<sph11>";
                            else if (TxtSize.Text == "3.0")
                                fgl_command = "<sph14>";
                            else if (TxtSize.Text == "3.25")
                                fgl_command = "<sph20>";
                            text_command = "Reverse Adjustable " + TxtSize.Text + " Path 2";
                            break;
                        case "BOTH":
                            if (TxtSize.Text == "2.0")
                                fgl_command = "<sph6>";
                            else if (TxtSize.Text == "2.125")
                                fgl_command = "<sph18>";
                            else if (TxtSize.Text == "2.5")
                                fgl_command = "<sph9>";
                            else if (TxtSize.Text == "2.7")
                                fgl_command = "<sph12>";
                            else if (TxtSize.Text == "3.0")
                                fgl_command = "<sph15>";
                            else if (TxtSize.Text == "3.25")
                                fgl_command = "<sph21>";
                            text_command = "Reverse Adjustable " + TxtSize.Text + " Path 2";
                            break;
                        default:
                            break;
                    }
                    break;
                default:
                    fgl_command = "<sph0>";           //No Special Head
                    text_command = "No Special Head";
                    break;
            }
        
            //Verify there is a command to issue
            if (fgl_command != "")
            {
                //prepend the tranparent mode off command to outgoing configuration commands
                fgl_command = "<n>" + fgl_command;

                //Issue command
                m_parent.Transmit(fgl_command);
        
                //Echo command sent to screen
                m_parent.Display_Text("Sent " + text_command + " command " + fgl_command + " to the printer.");
        
            }
            else
                m_parent.Display_Text("No Command was Sent to the printer.");       //Display command on screen
    


        }
    }
}
