﻿namespace EthernetPort
{
    //Version 6.2.0.0 updates below include more detailed messsges in the exception handlers
    
    using System;
    using System.IO;
    using System.Threading;
    using System.Runtime.InteropServices;
    using Microsoft.Win32.SafeHandles;
    using System.Net.Sockets;
    using System.Net.NetworkInformation;
    using System.Text;
    using System.Windows.Forms;

    public class PortAccess
    {
        public static TcpClient client;
        public static Stream s;
        public static StreamReader sr;
        public static StreamWriter sw;
        public static BinaryWriter sb;
        
        //thread for read operations
        protected Thread dataReadingThread;
        public static PortAccess boca_ip;
        private boca_sample.FrmBoca m_parent;

        public PortAccess(boca_sample.FrmBoca frm1)
        {
            //create Read Thread
            dataReadingThread = new Thread(new ThreadStart(readDataThread));
            m_parent = (boca_sample.FrmBoca)frm1;
            boca_ip = this;
        }

        //arg can be an IPaddress or host name.
        public static PingReply pinger(string arg)
        {
            Ping pingSender = new Ping();
            PingOptions options = new PingOptions();

            // Use the default Ttl value which is 128, but change the fragmentation behavior.
            options.DontFragment = true;

            // Create a buffer of 32 bytes of data to be transmitted.
            string data = "BocaSystemsBocaSystemsBocaSystem";
            byte[] buffer = Encoding.ASCII.GetBytes(data);
            int timeout = 120;
            PingReply reply = pingSender.Send(arg, timeout, buffer, options);
            return (reply);
        }
   
        public static bool open_ip(string ip_address)
        {
            bool status = true;             //set for success
            try
            {

                //establish connection to ip address provided using port 9100
                client = new TcpClient(ip_address, 9100);

                s = client.GetStream();
                s.ReadTimeout = 500;        //attempt to read for up to 0.5 seconds
                sr = new StreamReader(s);   //create read stream
                sw = new StreamWriter(s);   //create write stream
                sb = new BinaryWriter(s);   //create binary stream
                sw.AutoFlush = true;        //set write stream to flush data when < full buffer
                boca_ip.readData();         //start read thread
                
            }
            catch (Exception ex)                        //Version 6.2.0.0
            {
                MessageBox.Show("Unable to Connect to ip address " + ex.Message + " " + ex.StackTrace);
                status = false;                         //reset to failure
            }
            return (status);
        }

        public static bool close_ip()
        {
            bool status = true;             //set for success

            try
            {
                boca_ip.readData();         //stop read thread
                s.Close();                  //close streams
                client.Close();             //close client
                //Thread.Sleep(500);          //Insert 1/2 second delay for testing, to see if Open error goes away
            }
            catch (Exception ex)                        //Version 6.2.0.0
            {
                MessageBox.Show("Unable to Close connection to open ip address " + ex.Message + " " + ex.StackTrace);
                status = false;                         //reset to failure
            }
            return (status);
        }

        public static bool write_ip(string command)
        {
            bool status = true;             //set for success
            try
            {
                sw.WriteLine(command);
                //sw.Flush();                             //Insert Flush command to eliminated need for multiple Open/Close commands
            }
            catch (Exception ex)                        //Version 6.2.0.0
            {
                MessageBox.Show("Unable to transmit to open ip address " + ex.Message + " " + ex.StackTrace);
                status = false;                         //reset to failure
            }
            return (status);
        }

        public static bool write_ipb(byte[] command)
        {
            bool status = true;             //set for success
            int j;

            //sw.write uses char[] not byte[] so convert
            char[] oc = new char[command.Length];
            for (j = 0; j < command.Length; j++)
                oc[j] = (char)command[j];
 
            try
            {
                sb.Write(command, 0, command.Length);
            }
            catch (Exception ex)                        //Version 6.2.0.0
            {
                MessageBox.Show("Unable to transmit to open ip address " + ex.Message + " " + ex.StackTrace);
                status = false;                         //reset to failure
            }
            return (status);
        }

        public static string receive_ip()
        {
            string incoming="";                                     //clear return buffer
            char[] indata = new char[client.Available];             //sr.read into character array
            int count,x;

            while (client.Available > 0)
            {
                try
                {
                count = sr.Read(indata, 0, client.Available);    //read data into character array
                for (x = 0; x < count; x++)                      //convert to string
                   incoming += indata[x].ToString();

                }
                catch (Exception ex)                            //Version 6.2.0.0
                {
                    MessageBox.Show("Unable to receive from open ip address " + ex.Message + " " + ex.StackTrace);
                }
            }
        return (incoming);                                      //return string
        }               //end receive_ip

        public void readDataThread()
        {
            while (boca_sample.FrmBoca.checking_for_data)
            {
                //check for data available to read until thread is stopped
                if (client.Available > 0)
                {
                    m_parent.incoming = receive_ip();                        //perform read
                    if (m_parent.incoming.Length > 0)                         //if read successful
                        m_parent.Establish_Status();
                }
            }
        }               //end of read data thread

        public void readData()
        {

            if (dataReadingThread.ThreadState.ToString() == "Unstarted")
            {
                //start the thread
                dataReadingThread.Start();
                Thread.Sleep(0);
            }
            else if (dataReadingThread.ThreadState.ToString() == "Running")
            {
                boca_sample.FrmBoca.checking_for_data = false;
                //Stop the Thread
                dataReadingThread.Abort();
                Thread.Sleep(0);
            }
            else
            {
                //create Read Thread
                dataReadingThread = new Thread(new ThreadStart(readDataThread));
                Thread.Sleep(0);

                boca_sample.FrmBoca.checking_for_data = true;

                //start the thread
                dataReadingThread.Start();
                Thread.Sleep(0);

            }
        }        
    }       //end of class portaccess
}           //end of namespace Ethernet

